@@ -1,4 +1,5 @@
 import requests
+import bs4
 from bs4 import BeautifulSoup
 import urllib.parse as parse
 import re
@@ -6,12 +7,20 @@ import argparse
 
 from deep_translator import GoogleTranslator
 
+from selenium import webdriver
+from webdriver_manager.chrome import ChromeDriverManager
+
 def translate(lang, text):
 	return GoogleTranslator(source='auto', target=lang).translate(text)
 
 def about(lang, name):
 	name = name.replace(" ", "-")
 	search_url = ("https://www.anime-planet.com/anime/" + name)
+
+	driver = webdriver.Chrome(ChromeDriverManager().install())
+	driver.maximize_window()
+	driver.get(search_url)
+
 	source_code = requests.get(search_url)
 	content = source_code.content
 	soup = BeautifulSoup(content, features="html.parser")
@@ -23,6 +32,11 @@ def about(lang, name):
 def episodes(name):
 	name = name.replace(" ", "-")
 	search_url = ("https://www.anime-planet.com/anime/" + name)
+
+	driver = webdriver.Chrome(ChromeDriverManager().install())
+	driver.maximize_window()
+	driver.get(search_url)
+
 	source_code = requests.get(search_url)
 	content = source_code.content
 	soup = BeautifulSoup(content, features="html.parser")
@@ -34,6 +48,11 @@ def episodes(name):
 def years(name):
 	name = name.replace(" ", "-")
 	search_url = ("https://www.anime-planet.com/anime/" + name)
+
+	driver = webdriver.Chrome(ChromeDriverManager().install())
+	driver.maximize_window()
+	driver.get(search_url)
+
 	source_code = requests.get(search_url)
 	content = source_code.content
 	soup = BeautifulSoup(content, features="html.parser")
@@ -45,6 +64,11 @@ def years(name):
 def rating(lang, name):
 	name = name.replace(" ", "-")
 	search_url = ("https://www.anime-planet.com/anime/" + name)
+
+	driver = webdriver.Chrome(ChromeDriverManager().install())
+	driver.maximize_window()
+	driver.get(search_url)
+
 	source_code = requests.get(search_url)
 	content = source_code.content
 	soup = BeautifulSoup(content, features="html.parser")
@@ -56,6 +80,11 @@ def rating(lang, name):
 def tags(lang, name):
 	name = name.replace(" ", "-")
 	search_url = ("https://www.anime-planet.com/anime/" + name)
+
+	driver = webdriver.Chrome(ChromeDriverManager().install())
+	driver.maximize_window()
+	driver.get(search_url)
+	
 	source_code = requests.get(search_url)
 	content = source_code.content
 	soup = BeautifulSoup(content, features="html.parser")
